ci2adj: Get adjacency matrix for estimated networks based on credible...

Description Usage Arguments Value Examples

View source: R/post_functions.R

Description

Get adjacency matrix for estimated networks based on credible intervals

Usage

1
ci2adj(obj, weighted = FALSE)

Arguments

obj

An object of class mdine

weighted

Logical: should the adjacency matrices be weighted according to the corresponding partial correlation matrix?

Value

A list containing adjacency matrices for the two estimated precision matrices

Examples

1
2
3
4
5
6
library(mdine)
data(crohns)

X <- model.matrix(~disease, data=crohns$covars)
md.fit <- mdine(Y=crohns$otu.counts, X=X, Z=X[,2], mc.cores=1, iter=1000)
adj <- ci2adj(md.fit, weighted = TRUE)

kevinmcgregor/mdine documentation built on April 10, 2021, 4:18 a.m.