sig_diff_prec: Get which elements of the precision matrices differ...

Description Usage Arguments Value Examples

View source: R/post_functions.R

Description

Get which elements of the precision matrices differ significantly

Usage

1

Arguments

obj

An object of class mdine

Value

A matrix with a 1 if that element of the precision matrix differs significantly with respect to the binary covariate

Examples

1
2
3
4
5
6
library(mdine)
data(crohns)

X <- model.matrix(~disease, data=crohns$covars)
md.fit <- mdine(Y=crohns$otu.counts, X=X, Z=X[,2], mc.cores=1, iter=1000)
sig_diff_prec(md.fit)

kevinmcgregor/mdine documentation built on April 10, 2021, 4:18 a.m.