Description Usage Arguments Value Examples
View source: R/post_functions.R
Get adjacency matrix for estimated networks based on credible intervals
1 |
obj |
An object of class |
weighted |
Logical: should the adjacency matrices be weighted according to the corresponding partial correlation matrix? |
A list containing adjacency matrices for the two estimated precision matrices
1 2 3 4 5 6 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.