Description Usage Arguments Value Examples
View source: R/post_functions.R
Get which elements of the precision matrices differ significantly
1 | sig_diff_prec(obj)
|
obj |
An object of class |
A matrix with a 1 if that element of the precision matrix differs significantly with respect to the binary covariate
1 2 3 4 5 6 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.